turkish

Macro turkish 

turkish!() { /* proc-macro */ }
Available on crate features lang-turkish and macros only.
Construct a Turkish petname generator from word list files at compile time.

Like english!, but for petname::lang::Turkish. The adjectives file uses the same whitespace-delimited format, except a token may carry an emphatic (reduplicated) form after an =, e.g. kırmızı=kıpkırmızı. The adverbs and nouns files are plain whitespace-delimited words.

let t = petname::turkish!("words/turkish");